pub enum Error {
RequestError {
source: Error,
},
ResponseParsingError {
body: String,
},
HeaderConstruction {
source: InvalidHeaderValue,
},
ClientConstruction {
source: Error,
},
UrlConstruction,
}Expand description
Contains all possible errors of the crate
Variants
RequestError
Something went wrong during fetching of the ipbase api
ResponseParsingError
Something went wrong during the parsing of the ipbase api response.
HeaderConstruction
Something went wrong during header construction
Fields

source: InvalidHeaderValueError source
ClientConstruction
Something went wrong during http client creation
UrlConstruction
Failed to parse the request url